@@ -2,17 +2,18 @@ import fiftyone as fo
 import fiftyone.core.view as fov
 
 
-def annotate(dataset_or_view, label_field="ground_truth", label_type="instances",
+def annotate(batch, samples, label_field="ground_truth", label_type="instances",
              url="http://119.23.212.113:6060", username="hejian", password="LFIcvat123",
-             task_size=2000, segment_size=1000, task_assignee="hejian", job_assignees=["weiqiaomu", "jiasiyu"]):
+             task_size=1500, segment_size=500, task_assignee="hejian", job_assignees=["weiqiaomu", "jiasiyu"]):
     """Exports the samples to the given annotation backend.
 
     ``mask_targets`` is a dict mapping pixel values to semantic label strings.
     Only applicable when annotating semantic segmentations. the default is
-    ``dataset_or_view.default_mask_targets``.
+    ``samples.default_mask_targets``.
 
     Args:
-        dataset_or_view: a :class:`fiftyone.core.collections.SampleCollection`
+        batch: a name of str or index of int for samples
+        samples: a :class:`fiftyone.core.collections.SampleCollection`
         label_field ("ground_truth"): a string indicating a new or existing label field to annotate
         label_type ("instances"): a string indicating the type of labels to annotate. The possible values are:
 
@@ -47,19 +48,22 @@ def annotate(dataset_or_view, label_field="ground_truth", label_type="instances"
         url (str, optional): defaults to "http://119.23.212.113:6060"
         username (str, optional): defaults to "hejian"
         password (str, optional): defaults to "LFIcvat123"
-        task_size (int, optional): defaults to 2000
-        segment_size (int, optional): defaults to 1000
+        task_size (int, optional): defaults to 1500
+        segment_size (int, optional): defaults to 500
         task_assignee (str, optional): defaults to "hejian"
         job_assignees (list, optional): defaults to ``["weiqiaomu", "jiasiyu"]``
     """
     assert label_type in {"classification", "classifications", "detections", "instances", "polylines", "polygons", "keypoints", "segmentation", "scalar"}
 
-    if isinstance(dataset_or_view, fov.DatasetView):
-        dataset_name = dataset_or_view.dataset_name
+    if isinstance(samples, fov.DatasetView):
+        dataset_name = samples.dataset_name
     else:
-        dataset_name = dataset_or_view.name
+        dataset_name = samples.name
 
-    anno_key = f"{dataset_name}_{label_field}_{label_type}"
+    anno_key = f"{dataset_name}_{label_field}_{label_type}_{batch}"
+
+    if anno_key in samples.list_annotation_runs():
+        samples.delete_annotation_run(anno_key)
 
     # The new attributes that we want to populate
     attributes = True
@@ -72,13 +76,13 @@ def annotate(dataset_or_view, label_field="ground_truth", label_type="instances"
             }
         }
 
-    dataset_or_view.annotate(
+    samples.annotate(
         anno_key,
         label_field=label_field,
         label_type=label_type,
-        classes=dataset_or_view.default_classes or None,
+        classes=samples.default_classes or None,
         attributes=attributes,
-        mask_targets=dataset_or_view.default_mask_targets or None,
+        mask_targets=samples.default_mask_targets or None,
         launch_editor=False,
         url=url,
         username=username,
@@ -91,19 +95,22 @@ def annotate(dataset_or_view, label_field="ground_truth", label_type="instances"
         project_name=anno_key,
     )
 
-    return {"dataset_name": dataset_name, "anno_key": anno_key}
+    return anno_key
 
 
-def load_annotations(dataset_name, anno_key, cleanup=True,
+def load_annotations(dataset_name, anno_keys, cleanup=True,
                      url="http://119.23.212.113:6060", username="hejian", password="LFIcvat123"):
     dataset = fo.load_dataset(dataset_name)
 
-    dataset.load_annotations(
-        anno_key,
-        cleanup=cleanup,
-        url=url,
-        username=username,
-        password=password,
-    )
+    assert isinstance(anno_keys, list)
+
+    for anno_key in anno_keys:
+        dataset.load_annotations(
+            anno_key,
+            cleanup=cleanup,
+            url=url,
+            username=username,
+            password=password
+        )
 
     return dataset
